## START: Set by rpmautospec
## (rpmautospec version 0.6.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 2;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%ifnarch s390x
%bcond_without tests
%else
%if 0%{?el8}
# ConnectionTest fails
%bcond_with    tests
%else
%bcond_without tests
%endif
%endif

%ifarch s390x
# UniversalStackTrace fails with undefined references
%bcond_with    unwind
%else
%bcond_without unwind
%endif

%global _firewalld_dir %{_prefix}/lib/firewalld

Name:           et
Version:        6.2.8
Release:        %autorelease
Summary:        Remote shell that survives IP roaming and disconnect

License:        Apache-2.0
URL:            https://mistertea.github.io/EternalTerminal/
Source0:        https://github.com/MisterTea/EternalTerminal/archive/et-v%{version}.tar.gz
Source1:        et.xml
Patch2:         et-unbundle-deps.diff

BuildRequires:  boost-devel
BuildRequires:  cmake3
BuildRequires:  firewalld-filesystem
BuildRequires:  gcc-c++
# -static BR required for tracking of header-only libraries
BuildRequires:  cpp-httplib-devel
BuildRequires:  cpp-httplib-static
BuildRequires:  cxxopts-devel
BuildRequires:  cxxopts-static
BuildRequires:  easyloggingpp-devel
BuildRequires:  easyloggingpp-static
BuildRequires:  gflags-devel
BuildRequires:  json-devel
BuildRequires:  json-static
BuildRequires:  libatomic
BuildRequires:  libcurl-devel
BuildRequires:  libsodium-devel
%if %{with unwind}
BuildRequires:  libunwind-devel
%endif
BuildRequires:  libutempter-devel
BuildRequires:  ncurses-devel
BuildRequires:  openssl-devel
BuildRequires:  protobuf-compiler
BuildRequires:  protobuf-lite-devel
BuildRequires:  libselinux-devel
BuildRequires:  systemd

# Bundled libraries
# cat .gitmodules | grep submodule | sort
# for tarball, s/external/external_imported
Provides:       bundled(base64) = 0
# external_imported/catch2/meson.build
# see rhbz#2278059 for upgrading the system Catch2
Provides:       bundled(catch2) = 3.3.2
# external_imported/cotire/CMake/cotire.cmake
Provides:       bundled(cotire) = 1.8.0
# external/msgpack-c/include/msgpack/version_master.h
Provides:       bundled(msgpack) = 3.3.0
# external/PlatformFolders/CMakeLists.txt
Provides:       bundled(PlatformFolders) = 4.0.0
# sanitizers-cmake is only used when building
%ifnarch ppc64le s390x
# external/sentry-native/include/sentry.h
Provides:       bundled(sentry-native) = 0.6.0
%endif
# external/simpleini/SimpleIni.h
# can't use system simpleini - missing ConvertUTF.c
Provides:       bundled(simpleini) = 4.17
# https://github.com/r-lyeh-archived/sole
Provides:       bundled(sole) = 1.0.1
Provides:       bundled(ThreadPool) = 0
# external/UniversalStacktrace/CMakeLists.txt
Provides:       bundled(UniversalStacktrace) = 0.0.1
# vcpkg is disabled

%{?systemd_requires}

%description
Eternal Terminal (ET) is a remote shell that automatically reconnects without
interrupting the session.


%prep
%autosetup -p1 -n EternalTerminal-et-v%{version}
# use this if we have patches we need to apply by hand
# %%setup -q -n EternalTerminal-et-v%%{version}

# Remove bundled Catch2 test framework
# TODO: reenable after upgrading catch2 >= 3.3.2
# rm -rf external_imported/Catch2

# Unbundle cpp-httplib
rm -rf external_imported/cpp-httplib

# Unbundle cxxopts
rm -rf external_imported/cxxopts

# Unbundle easyloggingpp
rm -rf external_imported/easyloggingpp

# Unbundle “JSON for Modern C++”
rm -rf external_imported/json
# both /usr/share/cmake/nlohmann_json/nlohmann_jsonConfig.cmake
# and /usr/share/pkgconfig/nlohmann_json.pc are wrong
# so we can't use find_package / pkg_check_module without further hacks anyway
#sed -r -i 's@\$\{.*\}/json/include@%{_includedir}/nlohmann@' \
#    CMakeLists.txt


%build
%cmake \
%ifarch ppc64le s390x
  -DDISABLE_SENTRY:BOOL=TRUE \
%endif
  -DDISABLE_VCPKG:BOOL=TRUE \
  -DUSE_SYSTEM_PKGS:BOOL=TRUE
%cmake_build


%install
%cmake_install
mkdir -p \
  %{buildroot}%{_unitdir} \
  %{buildroot}%{_sysconfdir} \
  %{buildroot}%{_firewalld_dir}/services
install -m 0644 -p systemctl/et.service %{buildroot}%{_unitdir}/et.service
install -m 0644 -p etc/et.cfg %{buildroot}%{_sysconfdir}/et.cfg
install -m 0644 %{SOURCE1} %{buildroot}%{_firewalld_dir}/services/et.xml


%if %{with tests}
%check
%if 0%{?fedora}
%ctest
%else
%ctest --verbose
%endif
%endif


%post
%systemd_post et.service
%firewalld_reload

%preun
%systemd_preun et.service

%postun
%systemd_postun_with_restart et.service
%firewalld_reload


%files
%license LICENSE
%doc README.md
%{_bindir}/et
%{_bindir}/etserver
%{_bindir}/etterminal
%{_bindir}/htm
%{_bindir}/htmd
%dir %{_firewalld_dir}
%dir %{_firewalld_dir}/services
%{_firewalld_dir}/services/et.xml
%config(noreplace) %{_sysconfdir}/et.cfg
%{_unitdir}/et.service


%changelog
## START: Generated by rpmautospec
* Wed May 01 2024 Michel Lind <salimma@fedoraproject.org> - 6.2.8-2
- Fix s390x test gating

* Wed May 01 2024 Michel Lind <salimma@fedoraproject.org> - 6.2.8-1
- Update to 6.2.8 (rhbz#2162155)
- Temporarily rebundle catch2; the version in Fedora is too old

* Wed May 01 2024 Michel Lind <salimma@fedoraproject.org> - 6.2.1-9
- Disable unwind on s390x

* Wed May 01 2024 Michel Lind <salimma@fedoraproject.org> - 6.2.1-8
- Unbundle cpp-httplib (rhbz#2169585)
- Eliminate almost all sed usage
- Use find_package to find cxxopts
- Use pkg_check_modules to find easylogging++
- Enable SELinux support
- Enable unwind support

* Wed May 01 2024 Michel Lind <salimma@fedoraproject.org> - 6.2.1-7
- Use SPDX license identifier

* Wed May 01 2024 Davide Cavalca <dcavalca@fedoraproject.org> - 6.2.1-6
- Unbreak the build; Fixes: RHBZ#2242330, RHBZ#2225796, RHBZ#2171485

* Wed May 01 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 6.2.1-5
- Unbundle cxxopts

* Wed May 01 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 6.2.1-4
- Unbundle json (“JSON for Modern C++”)

* Wed May 01 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 6.2.1-3
- Unbundle easyloggingpp

* Sat May 07 2022 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.2.1-2
- Fix %%%%cmake invocation to make it work on Rawhide

* Sat May 07 2022 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.2.1-1
- Update to 6.2.1

* Sat May 07 2022 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.1.11-1
- Update to 6.1.11; Unbundle Catch2 (Benjamin A. Beasley
  <code@musicinmybrain.net>)

* Thu Nov  4 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.1.9-1
- Update to 6.1.9

* Wed Nov  3 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.1.8-2.20211103git900348b
- Red fixes

* Sun Jul 11 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.1.8-1
- Update to 6.1.8

* Mon Apr 26 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.1.7-1
- Update to 6.1.7

* Tue Mar 16 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.1.4-1
- Update to 6.1.4
- Fix for SIGSTKSZ/MINSIGSTKSZ non-constant on glibc > 2.33
- Declare bundled libraries

* Thu Nov 19 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.0.13-1
- Update to 6.0.13

* Thu Nov  5 2020 Filipe Brandenburger <filbranden@gmail.com> - 6.0.11-3
- Go back to using protobuf-lite on epel8, since the -devel package
  for it is now available (rhbz#1787458).

* Mon Aug  3 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.0.11-1
- Update to 6.0.11
- Use the new option to specify linking against the full protobuf on EPEL
- Adjust for cmake macro changes

* Tue Mar  3 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.0.7-1
- Update to 6.0.7

* Tue Feb 18 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.0.6-1
- Update to 6.0.6

* Sun Feb  2 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.0.5-1
- Initial build for EPEL 8

## END: Generated by rpmautospec
